@@ -2,15 +2,16 @@ import numpy as np
 
 
 class NumericEval:
-
     def __init__(self, d, mini_language):
 
-        self.d = d # dictionary of substitutions
-        for k,v in d.items():
-            assert(isinstance(k, str))
+        self.d = d  # dictionary of substitutions
+        for k, v in d.items():
+            assert isinstance(k, str)
 
         self.__supported_functions___ = supported_functions
-        self.__supported_functions_names___ = [fun.__name__ for fun in self.__supported_functions___]
+        self.__supported_functions_names___ = [
+            fun.__name__ for fun in self.__supported_functions___
+        ]
 
     def __call__(self, s):
 
@@ -19,7 +20,7 @@ class NumericEval:
     def eval(self, struct):
 
         t = struct.__class__.__name__
-        method_name = 'eval_' + t.lower()
+        method_name = "eval_" + t.lower()
         try:
             fun = getattr(self, method_name)
         except Exception as e:
@@ -55,19 +56,19 @@ class NumericEval:
                 if isinstance(args, dict):
                     eargs = self.eval(args)
                     res = fun(**eargs)
-                elif isinstance(args, (list,tuple)):
+                elif isinstance(args, (list, tuple)):
                     eargs = self.eval(args)
                     res = fun(*eargs)
                 else:
                     res = args
                 return res
 
-
-        return {k: self.eval(e) for k,e in d.items()}
+        return {k: self.eval(e) for k, e in d.items()}
 
     def eval_ordereddict(self, s):
 
         from collections import OrderedDict
+
         res = OrderedDict()
         for k in s.keys():
             v = self.eval(s[k])
@@ -77,15 +78,17 @@ class NumericEval:
 
     def eval_ndarray(self, array_in):
         import numpy
+
         array_out = numpy.zeros_like(array_in, dtype=float)
         for i in range(array_in.shape[0]):
             for j in range(array_in.shape[1]):
-                array_out[i,j] = self.eval(array_in[i,j])
+                array_out[i, j] = self.eval(array_in[i, j])
         return array_out
 
     def eval_nonetype(self, none):
         return None
 
+
 ###
 ### Mini language example
 ###
@@ -130,7 +133,6 @@ class NumericEval:
 # ###
 
 
-
 # # Markov mini language
 
 # if __name__ == '__main__':
@@ -150,7 +152,6 @@ class NumericEval:
 #     print( NumericEval(d, supported_functions)(options) )
 
 
-
 #         # define a markov chain in yaml
 #     txt = '''
 # tensor:
@@ -165,8 +166,6 @@ class NumericEval:
 #         b: 1.2
 
 
-
-
 #     '''
 #     import yaml
 #     s = yaml.safe_load(txt)
